@@ -7,7 +7,7 @@ Abstract function optimisation.
 
 """
 from . import testing
-from ._test import test
+from .testit import test
 from .check_grad import approx_fprime, check_grad
 from .exception import OptimixError
 from .function import Function, FunctionReduce
@@ -15,7 +15,7 @@ from .optimize import maximize, maximize_scalar, minimize, minimize_scalar
 from .types import Matrix, Scalar, Vector
 
 __name__ = "optimix"
-__version__ = "1.2.20"
+__version__ = "1.2.21"
 __author__ = "Danilo Horta"
 __author_email__ = "horta@ebi.ac.uk"
 
