@@ -1,5 +1,5 @@
 from numpy import asarray, atleast_1d
-from numpy.testing import assert_allclose
+from numpy.testing import assert_, assert_allclose
 
 from optimix import Scalar, Vector
 
@@ -8,36 +8,36 @@ def test_types_scalar_comparison():
     a = Scalar(1.0)
     b = Scalar(2.0)
 
-    assert a < b
-    assert a <= b
-    assert a != b
+    assert_(a < b)
+    assert_(a <= b)
+    assert_(a != b)
 
     b.value = 1.0
 
-    assert a == b
+    assert_(a == b)
 
 
 def test_types_scalar_fix():
     a = Scalar(1.0)
 
-    assert not a.isfixed
+    assert_(not a.isfixed)
 
     a.fix()
-    assert a.isfixed
+    assert_(a.isfixed)
 
 
 def test_types_scalar_copy():
     a = Scalar(1.0)
     b = a.copy()
 
-    assert a is not b
-    assert a == b
+    assert_(a is not b)
+    assert_(a == b)
 
 
 def test_types_scalar_listen():
     a = Scalar(1.0)
 
-    class Listener(object):  # pylint: disable=R0903
+    class Listener(object):
         def __init__(self):
             self.value = None
 
@@ -48,43 +48,63 @@ def test_types_scalar_listen():
     a.listen(l)
     a.value = 3.0
 
-    assert l.value == 3.0
+    assert_(l.value == 3.0)
+
+
+def test_types_scalar_listen_indirect():
+    a = Scalar(1.0)
+
+    class Listener(object):
+        def __init__(self):
+            self.value = None
+
+        def __call__(self, value):
+            self.value = value
+
+    l = Listener()
+
+    a.listen(l)
+
+    value = a.value
+    value.itemset(3.0)
+
+    assert_(l.value == 3.0)
 
 
 def test_types_vector_comparison():
     a = Vector([1.0, 2.0])
     b = Vector([1.0, 1.5])
 
-    assert (a > b)[1]
-    assert (a == b)[0]
-    assert (a != b)[1]
+    assert_((a > b)[1])
+    assert_((a == b)[0])
+    assert_((a != b)[1])
 
     b.value = asarray([1.0, 2.0])
 
-    assert all(a == b)
+    assert_(all(a == b))
 
 
 def test_types_vector_fix():
     a = Vector([1.0, 2.0])
 
-    assert not a.isfixed
+    assert_(not a.isfixed)
 
     a.fix()
-    assert a.isfixed
+    assert_(a.isfixed)
 
 
 def test_types_vector_copy():
     a = Vector([1.0])
     b = a.copy()
 
-    assert a is not b
-    assert a == b
+    assert_(a is not b)
+    assert_(a == b)
 
 
 def test_types_vector_listen():
     a = Vector([1.0, 2.0])
 
-    class Listener(object):  # pylint: disable=R0903
+    class Listener(object):
         def __init__(self):
             self.value = None
 
@@ -101,7 +121,7 @@ def test_types_modify_scalar():
     a = Scalar(1.0)
     value = atleast_1d(a.value)
     value[0] = 2.0
-    assert a.value == value[0]
+    assert_(a.value == value[0])
 
 
 def test_types_modify_vector():
@@ -109,7 +129,3 @@ def test_types_modify_vector():
     value = atleast_1d(a.value)
     value[0] = 2.0
     assert_allclose(a.value, value)
-
-
-if __name__ == '__main__':
-    __import__('pytest').main([__file__, '-s'])
