@@ -1,4 +1,4 @@
-from numpy.testing import assert_allclose
+from numpy.testing import assert_, assert_allclose, assert_equal
 
 from optimix import Scalar
 from optimix.variables import Variables, merge_variables
@@ -8,8 +8,8 @@ def test_variables_set():
     a = Scalar(1.0)
     b = a
     a.value = 2.0
-    assert a is b
-    assert a.raw is b.raw
+    assert_(a is b)
+    assert_(a.raw is b.raw)
 
     v = Variables(dict(a=Scalar(1.0), b=Scalar(1.5)))
     v.set({'a': 0.5})
@@ -18,8 +18,9 @@ def test_variables_set():
 
 def test_variables_str():
     v = Variables(dict(a=Scalar(1.0), b=Scalar(1.5)))
-    assert v.__str__() == """Variables(a=Scalar(1.0),
-          b=Scalar(1.5))"""
+    msg = "Variables(a=Scalar(1.0),\n"
+    msg += " " * 10 + "b=Scalar(1.5))"
+    assert_equal(v.__str__(), msg)
 
 
 def test_variables_merge():
@@ -29,8 +30,8 @@ def test_variables_merge():
 
     a.get('a0').value += 1.0
 
-    assert a.get('a0').value == 2.0
-    assert a.get('a0').value == c.get('a.a0').value
+    assert_(a.get('a0').value == 2.0)
+    assert_(a.get('a0').value == c.get('a.a0').value)
 
 
 def test_variables_setattr():
@@ -39,9 +40,5 @@ def test_variables_setattr():
     a['a1'] = Scalar(2.0)
     a['a1'].value += 1.0
 
-    assert a.get('a0').value == 1.0
-    assert a.get('a1').value == 3.0
-
-
-if __name__ == '__main__':
-    __import__('pytest').main([__file__, '-s'])
+    assert_(a.get('a0').value == 1.0)
+    assert_(a.get('a1').value == 3.0)
